---
jupyter:
  kernelspec:
    display_name: Python 3
    language: python
    name: python3
  nbformat: 4
  nbformat_minor: 2
---

::: {.cell .markdown}
# Jupyter notebook

This notebook is a simple jupyter notebook. It only has markdown and code cells. And it does not contain consecutive markdown cells. We start with an addition:
:::

::: {#cell-1 .cell .code}
``` python
a = 1
b = 2
a + b
```
:::

::: {.cell .markdown}
Now we return a few tuples
:::

::: {#cell-2 .cell .code}
``` python
a, b
```
:::

::: {#cell-3 .cell .code}
``` python
a, b, a+b
```
:::

::: {.cell .markdown}
And this is already the end of the notebook
:::
